@@ -6,6 +6,10 @@ OC.L10N.register(
     "Personal" : "Personal",
     "Later" : "Después",
     "Mail" : "Correo",
+    "Connecting" : "Conectando",
+    "Save" : "Guardar",
+    "Connect" : "Conectar",
+    "Password required" : "Contraseña requerida",
     "Name" : "Nombre",
     "Mail address" : "Dirección de correo",
     "Password" : "Contraseña",
@@ -20,10 +24,6 @@ OC.L10N.register(
     "SMTP Port" : "Puerto SMTP",
     "SMTP User" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
-    "Connecting" : "Conectando",
-    "Save" : "Guardar",
-    "Connect" : "Conectar",
-    "Password required" : "Contraseña requerida",
     "Aliases" : "Aliases",
     "Signature" : "Firma",
     "Go back" : "Regresar",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Register" : "Registrar",
+    "About" : "Acerca de",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
     "Newer message" : "Mensaje más nuevo",
@@ -47,8 +48,8 @@ OC.L10N.register(
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
     "Add attachment from Files" : "Agregar adjunto desd Archivos",
-    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Choose" : "Seleccionar",
+    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Confirm" : "Confirmar",
     "Unfavorite" : "Quitar favorito",
     "Favorite" : "Hacer favorito",
@@ -67,23 +68,24 @@ OC.L10N.register(
     "email" : "correo electrónico",
     "Other" : "Otro",
     "Forward" : "Adelante",
+    "Translate" : "Traducir",
+    "Unnamed" : "Sin nombre",
     "Choose a folder to store the attachment in" : "Seleccciona la carpeta en la cual almacenar el adjunto",
     "Import into calendar" : "Importar al calendario",
     "Download attachment" : "Descargar adjunto",
     "Save to Files" : "Guardar a Archivos",
-    "Unnamed" : "Sin nombre",
     "Save all to Files" : "Guardar todo a Archivos",
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
+    "Remove account" : "Eliminar cuenta",
     "Quota" : "Cuota",
     "Saving" : "Guardando",
-    "Remove account" : "Eliminar cuenta",
     "Mark all as read" : "Marcar todos como leídos",
     "Clear cache" : "Borrar el caché",
     "New message" : "Mensaje nuevo",
+    "Reply" : "Responder",
     "Retry" : "Reintentar",
     "Sending …" : "Enviando ...",
-    "Reply" : "Responder",
     "Message" : "Mensaje",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Add" : "Agregar",
