@@ -52,14 +52,51 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
+    "No certificate" : "Sertifikaati pole",
+    "Certificate updated" : "Sertifikaat on uuendatud",
+    "Could not update certificate" : "Sertifikaadi uuendamine ei õnnestunud",
+    "{commonName} - Valid until {expiryDate}" : "{commonName} - Kehtiv kuni {expiryDate}",
+    "Select an alias" : "Vali alias",
+    "Select certificates" : "Vali sertifikaadid",
+    "Update Certificate" : "Uuenda sertifikaati",
+    "Send later" : "Saada hiljem",
+    "Message {id} could not be found" : "Kirja tunnusega „{id}“ ei õnnestu leida",
+    "Turn off formatting" : "Lülita vormindus välja",
+    "Turn off and remove formatting" : "Lülita välja ja eemalda vorming",
+    "Keep formatting" : "Säilita vorming",
     "From" : "Saatja",
+    "Select account" : "Vali kasutajakonto",
     "To" : "Saaja",
+    "Cc/Bcc" : "Cc/Bcc",
+    "Select recipient" : "Vali kirja saaja",
+    "Contact or email address …" : "Kontakt või e-posti aadress…",
+    "Cc" : "Cc",
+    "Bcc" : "Bcc",
     "Subject" : "Teema",
+    "Subject …" : "Teema…",
+    "This message came from a noreply address so your reply will probably not be read." : "See kiri on saadetud aadressilt, kuhu vastuseid ei oodata ja seega sinu saadetud vastust ilmselt mitte keegi ei loe.",
+    "Write message …" : "Koosta kiri…",
+    "Saving draft …" : "Salvestan kavandit…",
+    "Error saving draft" : "Viga kavandi salvestamisel",
+    "Draft saved" : "Kavand on salvestatud",
+    "Save draft" : "Salvesta kavand",
+    "Discard & close draft" : "Loobu muudatustest ja sulge kavand",
+    "Send now" : "Saada kohe",
+    "Tomorrow morning" : "Homme hommikul",
+    "Tomorrow afternoon" : "Homme pärastlõunal",
+    "Monday morning" : "Esmaspäeva hommikul",
+    "Custom date and time" : "Valutud kuupäeval ja kellaajal",
     "Enter a date" : "Sisesta kuupäev",
     "Choose" : "Vali",
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Confirm" : "Kinnita",
+    "Tag: {name} deleted" : "Silt: {name} on kustutatud",
+    "An error occurred, unable to delete the tag." : "Tekkis viga, silt ei õnnestu kustutada",
+    "Plain text" : "Vormindamata tekst",
+    "Rich text" : "Vormindatud tekst",
+    "No messages in this mailbox" : "Selles postkastis pole kirju",
+    "No messages" : "Kirju pole",
     "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
     "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
     "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
@@ -73,6 +110,7 @@ OC.L10N.register(
     "Back" : "Tagasi",
     "Create event" : "Lisa sündmus",
     "Create task" : "Loo ülesanne",
+    "Load more" : "Laadi veel",
     "_Mark {number} read_::_Mark {number} read_" : ["Märgi {number} loetuks","Märgi {number} loetuks"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Märgi {number} mitteloetuks","Märgi {number} mitteloetuks"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Märgi {number} oluliseks","Märgi {number} oluliseks"],
@@ -119,16 +157,35 @@ OC.L10N.register(
     "Move mailbox" : "Teisalda postkast",
     "Repair mailbox" : "Paranda postkasti",
     "Clear cache" : "Tühjenda puhver",
-    "New message" : "Uus sõnum",
-    "Edit message" : "Muuda sõnumit",
+    "New message" : "Uus kiri",
+    "Edit message" : "Muuda kirja",
+    "Draft" : "Kavand",
     "Reply" : "Vasta",
+    "Message saved" : "Kiri on salvestatud",
+    "Failed to save message" : "Kirja salvestamine ei õnnestu",
+    "Failed to save draft" : "Mustandi salvestamine ei õnnestu",
+    "attachment" : "manus",
+    "attached" : "manus on lisatud",
+    "No sent mailbox configured. Please pick one in the account settings." : "Väljuvate kirjade postkast on seadistamata. Palun see seda kasutajakonto seadistustes.",
     "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
+    "You mentioned an attachment. Did you forget to add it?" : "Sa mainisid, et tahad manuse lisada. Kas see ununes?",
+    "Could not discard message" : "Ei õnnestud kirja koostamisest ja saatmisest loobuda",
     "Show recipient details" : "Näita kirjasaaja üksikasju",
     "Hide recipient details" : "Peida kirjasaaja üksikasjad",
+    "Error sending your message" : "Viga kirja saatmisel",
     "Retry" : "Proovi uuesti",
-    "Sending …" : "Saadan ...",
+    "Uploading attachments …" : "Manused on üleslaadimisel…",
+    "Sending …" : "Saadan...",
+    "Warning sending your message" : "Hoiatus sinu kirja saatmisel",
+    "Send anyway" : "Saada ikkagi",
+    "Autoresponder off" : "Automaatvastaja on sees",
+    "Autoresponder on" : "Automaatvastaja on väljas",
+    "Autoresponder follows system settings" : "Automaatvastaja järgib süsteemi seadistusi",
+    "The autoresponder follows your personal absence period settings." : "Automaatvastaja järgib sinu isikliku äraoleku perioodi seadistusi.",
+    "Edit absence settings" : "Muuda äraoleku seadistusi",
     "First day" : "Esimene päev",
-    "Message" : "Sõnum",
+    "Message" : "Kiri",
+    "Save autoresponder" : "Salvesta automaatvastaja",
     "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
     "Hide suspicious links" : "Peida kahtlased lingid",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
@@ -137,6 +194,7 @@ OC.L10N.register(
     "Show more" : "Näita rohkem",
     "Clear" : "Tühjenda",
     "Close" : "Sulge",
+    "Body" : "Sisu",
     "Date" : "Kuupäev",
     "Tags" : "Sildid",
     "Select tags" : "Vali sildid",
@@ -195,6 +253,7 @@ OC.L10N.register(
     "User" : "Kasutaja",
     "Host" : "Host",
     "Port" : "Port",
+    "SMTP" : "SMTP",
     "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, et privaatvõti vastab sertifikaadile ja ta ei ole salafraasiga krüptitud.",
     "Failed to import the certificate" : "Sertifikaadi importimine ei õnnestunud",
     "S/MIME certificates" : "S/MIME sertifikaadid",
@@ -224,6 +283,7 @@ OC.L10N.register(
     "Junk" : "Rämpspost",
     "Sent" : "Saadetud",
     "Trash" : "Prügikast",
+    "Connect OAUTH2 account" : "Ühenda OAUTH2 autentimist kasutava kontoga",
     "Error while sharing file" : "Viga faili jagamisel",
     "{from}\n{subject}" : "{from}\n{subject}",
     "Discard changes" : "Hülga muudatused",
@@ -234,10 +294,12 @@ OC.L10N.register(
     "Could not send message" : "Kirja saatmine ei õnnestu",
     "Message copied to \"Sent\" mailbox" : "Kiri on kopeeritud „Saadetud“ postkasti",
     "Could not copy message to \"Sent\" mailbox" : "Kirja on kopeerimine „Saadetud“ postkasti ei õnnestunud",
-    "Error loading message" : "Tõrge kirja laadimisel",
+    "Error loading message" : "Viga kirja laadimisel",
     "Forwarding to %s" : "Edasta %s",
     "Redirect" : "Suunamine",
+    "The link leads to %s" : "Link viitab siia: %s",
     "Continue to %s" : "Jätka siit: %s",
+    "This event is in the past." : "See sündmus on jäänud minevikku.",
     "Collapse composer" : "Ahenda kirjutusvaade"
 },
 "nplurals=2; plural=(n != 1);");
