@@ -17,6 +17,7 @@ OC.L10N.register(
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "Kata sandi SMTP",
     "Signature" : "Tanda",
+    "Filters" : "Penyaring",
     "Go back" : "Kembali",
     "Email address" : "Alamat surel",
     "Cancel" : "Membatalkan",
@@ -57,6 +58,7 @@ OC.L10N.register(
     "Import into calendar" : "Impor ke kalender",
     "Download attachment" : "Unduh lampiran",
     "Move" : "Pindah",
+    "Loading …" : "Memuat …",
     "Remove account" : "Hapus akun",
     "Quota" : "Kuota",
     "Saving" : "Menyimpan",
@@ -75,6 +77,7 @@ OC.L10N.register(
     "Close" : "Tutup",
     "Date" : "Date",
     "Tags" : "Tag",
+    "Custom" : "Ubahan",
     "Tag already exists" : "Tag sudah ada",
     "Add tag" : "Tambahkan tag",
     "Unsubscribe" : "Berhenti berlangganan",
@@ -104,6 +107,7 @@ OC.L10N.register(
     "Sent" : "Kirim",
     "Trash" : "Tempat sampah",
     "{from}\n{subject}" : "{from}\n{subject}",
+    "Discard changes" : "Buang perubahan",
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
